@@ -24,7 +24,7 @@ actually being connected to any particular search engine.
 
 =head1 AUTHOR
 
-Martin Thurn <mthurn@cpan.org>
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
